#ifndef NT2_INCLUDE_FUNCTIONS_POLYINT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYINT_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyint.hpp>

#endif
